@@ -162,6 +162,11 @@ with this program; if not, write to the Free Software Foundation, Inc.,
 //! Additionally `Wikicode` does not implement [`Send`](https://doc.rust-lang.org/std/marker/trait.Send.html),
 //! which means it cannot be safely shared across threads. This is a
 //! limitation of the underlying kuchiki library being used.
+//!
+//! A `ImmutableWikicode` is provided as a workaround - it is `Send` and
+//! contains all the same information `Wikicode` does, but is immutable.
+//! Switching between the two is straightforward by using `to_immutable()` and
+//! `to_mutable()` or by using the standard `From` and `Into` traits.
 
 #[cfg(feature = "http")]
 mod api;
@@ -384,6 +389,10 @@ impl Wikicode {
     pub fn text_contents(&self) -> String {
         self.body_element().text_contents()
     }
+
+    pub fn to_immutable(self) -> immutable::ImmutableWikicode {
+        self.into()
+    }
 }
 
 impl From<Wikinode> for Wikicode {
