@@ -145,7 +145,9 @@ impl Wikinode {
                     }
                 }
                 local_name!("section") => {
-                    return Section::new_from_node(node).into();
+                    if attributes.contains("data-mw-section-id") {
+                        return Section::new_from_node(node).into();
+                    }
                 }
                 local_name!("span") => {
                     if let Some(type_of) = attributes.get("typeof") {
@@ -725,7 +727,9 @@ impl HtmlEntity {
     }
 }
 
-/// Section contains a `Heading` and its contents
+/// Section contains a `Heading` and its contents. This only covers sections
+/// generated by `== headings ==`, and not any `<section>` tag that might be
+/// present in the output (e.g. generated by an extension).
 ///
 /// It is not expected that this node will be created manually.
 ///
@@ -734,7 +738,7 @@ impl HtmlEntity {
 pub struct Section(NodeRef);
 
 impl Section {
-    pub(crate) const SELECTOR: &'static str = "section";
+    pub(crate) const SELECTOR: &'static str = "section[data-mw-section-id]";
 
     pub(crate) fn new_from_node(element: &NodeRef) -> Self {
         assert_element(element);
@@ -752,8 +756,12 @@ impl Section {
             .attributes
             .borrow()
             .get("data-mw-section-id")
+            // expect: Unreachable because this attribute is checked everywhere
+            // this node type is created
             .expect("No data-mw-section-id attribute on section")
             .parse()
+            // expect: This should be safe assuming we were provided
+            // well-formed HTML.
             .expect("Invalid data-mw-section-id attribute")
     }
 
