@@ -52,6 +52,19 @@ async fn test_get_revision() -> Result<()> {
     Ok(())
 }
 
+#[tokio::test]
+async fn test_get_redirect() -> Result<()> {
+    let client = Client::new(
+        "https://en.wikipedia.org/api/rest_v1",
+        "parsoid-rs testing",
+    )?;
+    let code = client.get("Main page").await?;
+    let redirect = code.get_redirect();
+    assert!(redirect.is_some());
+    assert_eq!(&redirect.unwrap().target(), "Main Page");
+    Ok(())
+}
+
 #[tokio::test]
 async fn test_transform_to_html() -> Result<()> {
     let client = Client::new(
